import 'package:flutter/material.dart';
import 'package:progress_state_button/iconed_button.dart';
import 'package:progress_state_button/progress_button.dart';
import '../constants.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

class LoadingButtonCubit extends Cubit<ButtonState> {
  LoadingButtonCubit() : super(ButtonState.idle);

  void setIdle() => Future.delayed(const Duration(milliseconds: 3000), () {
        emit(ButtonState.idle);
      });

  void setSuccess() => emit(ButtonState.success);

  void setError() => emit(ButtonState.fail);

  void setLoading() => emit(ButtonState.loading);
}

class DefaultLoadingButton extends StatelessWidget {
  final Color? backgroundColor;
  final IconData icon;
  final String title;
  final String? failText;
  final String? loadingText;
  final String? successText;
  final ButtonState buttonState;
  final Function onPressed;
  final double? width;
  final double? height;

  const DefaultLoadingButton(
      {Key? key,
      this.width,
      this.height,
      required this.onPressed,
      required this.buttonState,
      required this.backgroundColor,
      required this.icon,
      required this.title,
      this.failText,
      this.loadingText,
      this.successText})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: width ?? 150,
      height: height ?? 50,
      child: ProgressButton.icon(
        iconedButtons: {
          ButtonState.idle: IconedButton(
              text: title,
              icon: Icon(icon, color: Colors.white),
              color: backgroundColor ?? Colors.black),
          ButtonState.loading: IconedButton(
              text: loadingText ?? "Loading", color: defaultTitleColor),
          ButtonState.fail: IconedButton(
              text: failText ?? "Failed",
              icon: const Icon(Icons.cancel, color: Colors.white),
              color: defaultDangerColor),
          ButtonState.success: IconedButton(
              text: successText ?? "Success",
              icon: const Icon(
                Icons.check_circle,
                color: Colors.white,
              ),
              color: defaultSuccessColor)
        },
        onPressed: onPressed,
        state: buttonState,
        radius: defaultCornerRadius,
      ),
    );
  }
}
