import 'package:flutter/material.dart';

import '../constants.dart';

class DefaultDropdownFormField extends StatelessWidget {
  final String label;
  final Function(String? newValue) onChanged;
  final BoxConstraints? constraints;
  final String? value;
  final String hint;
  final bool? disabled;
  final bool? addDefaultBorder;
  final Color? labelColor;
  final IconData? prefixIcon;
  final List<String> items;

  const DefaultDropdownFormField({
    Key? key,
    required this.label,
    required this.onChanged,
    required this.items,
    required this.hint,
    this.addDefaultBorder,
    this.constraints,
    this.value,
    this.disabled,
    this.labelColor,
    this.prefixIcon,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      constraints: constraints,
      child: Padding(
        padding: const EdgeInsets.all(7.5),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text(
              label,
              style: TextStyle(
                color: labelColor ?? defaultSubTitleColor,
                fontSize: 14,
                fontWeight: FontWeight.w500,
              ),
            ),
            const SizedBox(height: 5),
            DropdownButtonFormField<String>(
              value: value,
              icon: const Icon(Icons.arrow_drop_down_rounded),
              iconSize: 24,
              decoration: InputDecoration(
                hintStyle: const TextStyle(fontSize: 16, color: Colors.grey),
                filled: true,
                prefixIcon: Icon(
                  prefixIcon,
                  size: 15,
                  color: defaultSubTitleColor,
                ),
                hintText: hint,
                enabledBorder: addDefaultBorder == true
                    ? const OutlineInputBorder(
                        borderSide: BorderSide(color: Colors.black12, width: 1),
                      )
                    : const OutlineInputBorder(borderSide: BorderSide.none),
                focusedBorder: const OutlineInputBorder(
                  borderSide: BorderSide(color: defaultPrimaryColor, width: 1),
                ),
                errorBorder: const OutlineInputBorder(
                  borderSide: BorderSide(color: defaultDangerColor, width: 1),
                ),
                contentPadding: const EdgeInsets.all(16),
                fillColor: disabled == true ? Colors.grey[200] : Colors.white,
              ),
              style: const TextStyle(color: defaultTitleColor),
              onChanged: onChanged,
              items: items.map<DropdownMenuItem<String>>((String value) {
                return DropdownMenuItem<String>(
                  value: value,
                  child: Text(value),
                );
              }).toList(),
            ),
          ],
        ),
      ),
    );
  }
}
