import 'package:flutter/material.dart';

import '../constants.dart';

class DefaultFormField extends StatelessWidget {
  final TextEditingController textEditingController;
  final TextInputType textInputType;
  final String hint;
  final String label;
  final String? Function(String?)? validator;
  final BoxConstraints? constraints;
  final int? numberOfLines;
  final bool? disabled;
  final bool? addDefaultBorder;
  final Color? labelColor;
  final IconData? prefixIcon;
  final bool? obscureText;

  const DefaultFormField({
    Key? key,
    required this.textEditingController,
    required this.textInputType,
    required this.hint,
    required this.label,
    this.validator,
    this.addDefaultBorder,
    this.constraints,
    this.numberOfLines,
    this.disabled,
    this.labelColor,
    this.prefixIcon,
    this.obscureText,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(7.5),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Text(
            label,
            style: TextStyle(
              color: labelColor ?? defaultSubTitleColor,
              fontSize: 14,
              fontWeight: FontWeight.w500,
            ),
          ),
          const SizedBox(height: 5),
          TextFormField(
            enabled: disabled == null ? true : !(disabled!),
            controller: textEditingController,
            obscureText: obscureText ?? false,
            keyboardType: textInputType,
            style: const TextStyle(color: Colors.black),
            decoration: InputDecoration(
              hintText: hint,
              hintStyle: const TextStyle(fontSize: 16, color: Colors.grey),
              filled: true,
              prefixIcon: prefixIcon != null
                  ? Icon(
                      prefixIcon,
                      size: 15,
                      color: defaultSubTitleColor,
                    )
                  : null,
              enabledBorder: addDefaultBorder == true
                  ? const OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.black12, width: 1),
                      borderRadius: BorderRadius.all(
                          Radius.circular(defaultCornerRadius)),
                    )
                  : const OutlineInputBorder(borderSide: BorderSide.none),
              focusedBorder: const OutlineInputBorder(
                borderSide: BorderSide(color: defaultPrimaryColor, width: 1),
                borderRadius:
                    BorderRadius.all(Radius.circular(defaultCornerRadius)),
              ),
              errorBorder: const OutlineInputBorder(
                borderSide: BorderSide(color: defaultDangerColor, width: 1),
                borderRadius:
                    BorderRadius.all(Radius.circular(defaultCornerRadius)),
              ),
              focusedErrorBorder: const OutlineInputBorder(
                borderSide: BorderSide(color: defaultDangerColor, width: 1),
                borderRadius:
                    BorderRadius.all(Radius.circular(defaultCornerRadius)),
              ),
              contentPadding: const EdgeInsets.all(16),
              fillColor: disabled == true ? Colors.grey[200] : Colors.white,
            ),
            validator: validator,
            maxLines: obscureText == true ? 1 : numberOfLines,
          ),
        ],
      ),
    );
  }
}
