import 'package:flutter/material.dart';
import 'package:google_nav_bar/google_nav_bar.dart';
import 'package:softcorp_flutter_core/default_card/default_card.dart';
import 'package:softcorp_flutter_core/details_profile_card/default_profile_card.dart';
import '../constants.dart';

class DefaultHeaderCard extends StatelessWidget {
  final Color? backgroundColor;
  final Widget child;
  final String title;
  final String subtitle;
  final Widget? icon;
  final int? currentIndex;
  final Function(int? value)? onTabChange;
  final bool? tabBarEnabled;
  final List<ProfileDetailsTab>? tabs;

  DefaultHeaderCard({
    Key? key,
    this.backgroundColor,
    required this.child,
    required this.title,
    required this.subtitle,
    required this.icon,
    this.currentIndex,
    this.onTabChange,
    this.tabBarEnabled,
    this.tabs,
  }) : super(key: key) {
    if (tabBarEnabled == true &&
        (tabs == null || currentIndex == null || onTabChange == null)) {
      throw Exception(
          "tabs enabled but onTabChange, currentIndex or tabs is null");
    }
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return DefaultCard(
      backgroundColor: backgroundColor ?? defaultCardColor,
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          ListTile(
            leading: icon ?? const SizedBox(),
            contentPadding: const EdgeInsets.all(20),
            tileColor: Colors.black,
            title: Text(
              title,
              style: const TextStyle(
                color: Colors.white,
                overflow: TextOverflow.ellipsis,
                fontSize: 22,
              ),
              maxLines: 1,
            ),
            subtitle: Text(
              subtitle,
              style: const TextStyle(
                color: Colors.white70,
                overflow: TextOverflow.ellipsis,
                fontSize: 16,
              ),
              maxLines: 2,
            ),
          ),
          if (tabBarEnabled == true)
            Container(
              height: 60,
              color: Colors.black,
              width: size.width,
              child: GNav(
                rippleColor: Colors.black87,
                hoverColor: Colors.white38,
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                tabBorderRadius: defaultCornerRadius,
                curve: Curves.easeOutExpo,
                duration: const Duration(milliseconds: 300),
                gap: 8,
                selectedIndex: currentIndex!,
                color: Colors.white,
                onTabChange: onTabChange,
                activeColor: Colors.black,
                tabMargin: const EdgeInsets.all(5),
                iconSize: 24,
                tabBackgroundColor: Colors.white,
                padding: const EdgeInsets.symmetric(
                    horizontal: 20, vertical: 10),
                // navigation bar padding
                tabs: tabs!.map((tab) {
                  return GButton(
                    icon: tab.icon,
                    text: tab.name,
                    onPressed: tab.onPressed,
                  );
                }).toList(),
              ),
            ),
          Padding(
            padding: const EdgeInsets.all(defaultPadding * 2),
            child: child,
          ),
        ],
      ),
    );
  }
}
