import 'dart:math';
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:google_nav_bar/google_nav_bar.dart';
import 'package:softcorp_flutter_core/default_card/default_card.dart';
import '../constants.dart';

class ProfileDetailsTab {
  final IconData icon;
  final String name;
  final Function onPressed;

  ProfileDetailsTab({
    required this.icon,
    required this.name,
    required this.onPressed,
  });
}

class DefaultProfileCard extends StatelessWidget {
  final Widget? background;
  final int height;
  final String title;
  final String? subTitle;
  final bool? actionsEnabled;
  final Function(String? value)? onSelectActionItem;
  final Map<String, String>? actionItemsLabelValueMap;
  final Widget icon;
  final bool? tabBarEnabled;
  final List<ProfileDetailsTab>? tabs;
  final String? objType;
  final double width;
  final Axis? direction;
  final int? currentIndex;
  final Function(int? value)? onTabChange;
  final double iconSize;
  final Widget? rightWidget;

  DefaultProfileCard(
      {Key? key,
      required this.height,
      required this.title,
      required this.icon,
      required this.width,
      required this.iconSize,
      this.background,
      this.currentIndex,
      this.actionsEnabled,
      this.onTabChange,
      this.onSelectActionItem,
      this.actionItemsLabelValueMap,
      this.tabBarEnabled,
      this.tabs,
      this.objType,
      this.direction,
      this.rightWidget,
      this.subTitle})
      : super(key: key) {
    if (actionsEnabled == true &&
        (onSelectActionItem == null || actionItemsLabelValueMap == null)) {
      throw Exception("actions enabled but onSelect is null");
    }
    if (tabBarEnabled == true &&
        (tabs == null || currentIndex == null || onTabChange == null)) {
      throw Exception(
          "tabs enabled but onTabChange, currentIndex or tabs is null");
    }
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.center,
      children: <Widget>[
        Column(
          children: <Widget>[
            SizedBox(
              width: double.infinity,
              height: direction == Axis.vertical ? height * .80 : height * .65,
              child: DefaultCard(
                child: Center(
                  child: Stack(
                    children: <Widget>[
                      Container(
                        alignment: Alignment.center,
                        child: background ??
                            Image.asset(
                              'assets/covers/cover1.jpg',
                              width: double.infinity,
                              fit: BoxFit.cover,
                            ),
                      ),
                      Container(
                        padding: const EdgeInsets.all(defaultPadding),
                        alignment: Alignment.topLeft,
                        child: Text(
                          objType ?? "",
                          style: const TextStyle(
                              color: Colors.white,
                              fontWeight: FontWeight.w500,
                              fontSize: 14.0),
                        ),
                      ),
                      Container(
                        padding: const EdgeInsets.all(defaultPadding),
                        alignment: Alignment.topRight,
                        child: rightWidget ?? const SizedBox(),
                      ),
                    ],
                  ),
                ),
              ),
            ),
            Container(height: height * .15, color: Colors.transparent),
          ],
        ),
        Container(
          width: width,
          padding: EdgeInsets.only(top: height * .40, right: 20.0, left: 20.0),
          child: SizedBox(
            height: direction == Axis.vertical
                ? height > 400
                    ? 200
                    : height * .75
                : height * .37,
            width: MediaQuery.of(context).size.width,
            child: DefaultCard(
              backgroundColor: Colors.white.withOpacity(0.95),
              child: Padding(
                padding: const EdgeInsets.all(defaultCardPadding),
                child: SizedBox(
                  width: width * 0.85,
                  child: Flex(
                    direction: direction ?? Axis.horizontal,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    mainAxisAlignment: direction == Axis.vertical
                        ? MainAxisAlignment.center
                        : MainAxisAlignment.spaceBetween,
                    children: [
                      Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          ClipRRect(
                            borderRadius:
                                BorderRadius.circular(defaultCornerRadius),
                            child: Container(
                              width: iconSize,
                              height: iconSize,
                              color: Colors.grey[200],
                              padding: const EdgeInsets.all(10),
                              child: icon,
                            ),
                          ),
                          const SizedBox(width: 20),
                          Padding(
                            padding: const EdgeInsets.all(5),
                            child: Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                Text(
                                  title,
                                  maxLines: 1,
                                  style: const TextStyle(
                                      color: defaultTitleColor,
                                      overflow: TextOverflow.ellipsis,
                                      fontSize: 22,
                                      fontWeight: FontWeight.w500),
                                ),
                                Text(
                                  subTitle ?? "",
                                  maxLines: 1,
                                  overflow: TextOverflow.ellipsis,
                                  style: const TextStyle(
                                      color: defaultSubTitleColor,
                                      fontSize: 16),
                                ),
                              ],
                            ),
                          ),
                        ],
                      ),
                      Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        mainAxisAlignment: direction == Axis.vertical
                            ? MainAxisAlignment.center
                            : MainAxisAlignment.spaceBetween,
                        children: [
                          if (tabBarEnabled == true)
                            GNav(
                              rippleColor: Colors.black87,
                              hoverColor: Colors.white38,
                              tabBorderRadius: defaultCornerRadius,
                              curve: Curves.easeOutExpo,
                              duration: const Duration(milliseconds: 300),
                              gap: 8,
                              selectedIndex: currentIndex!,
                              color: Colors.black,
                              onTabChange: onTabChange,
                              activeColor: Colors.white,
                              tabMargin: const EdgeInsets.all(5),
                              iconSize: 28,
                              tabBackgroundColor: Colors.black,
                              padding: const EdgeInsets.symmetric(
                                  horizontal: 20, vertical: 10),
                              // navigation bar padding
                              tabs: tabs!.map((tab) {
                                return GButton(
                                  icon: tab.icon,
                                  text: tab.name,
                                  onPressed: tab.onPressed,
                                );
                              }).toList(),
                            ),
                          if (actionsEnabled == true)
                            Align(
                              alignment: Alignment.topRight,
                              child: PopupMenuButton<String>(
                                shape: const RoundedRectangleBorder(
                                  borderRadius: BorderRadius.all(
                                    Radius.circular(defaultCornerRadius),
                                  ),
                                ),
                                icon: const Icon(
                                  Icons.more_horiz_rounded,
                                  color: Colors.black,
                                  size: 19,
                                ),
                                onSelected: onSelectActionItem,
                                itemBuilder: (BuildContext context) {
                                  return actionItemsLabelValueMap!.keys
                                      .map((String key) {
                                    return PopupMenuItem<String>(
                                      value: actionItemsLabelValueMap![key],
                                      child: Text(
                                        key,
                                      ),
                                    );
                                  }).toList();
                                },
                              ),
                            ),
                        ],
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        ),
      ],
    );
  }
}
