import 'package:flutter/material.dart';
import 'package:progress_state_button/progress_button.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/default_buttons/default_button.dart';
import 'package:softcorp_flutter_core/default_dropdown_field/default_dropdown_field.dart';
import 'package:softcorp_flutter_core/default_form_field/default_form_field.dart';
import 'package:softcorp_flutter_core/default_header_card/default_header_card.dart';
import 'package:softcorp_flutter_core/default_list_form/default_list_form.dart';
import 'package:softcorp_flutter_core/default_multi_select/default_multi_select.dart';
import 'package:softcorp_flutter_core/details_profile_card/default_profile_card.dart';
import 'package:softcorp_flutter_core/footer/default_footer.dart';
import 'package:softcorp_flutter_core/split_screen/split_screen.dart';
import 'package:websafe_svg/websafe_svg.dart';

import 'default_spinner/default_spinner.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() {
    return _MyAppState();
  }
}

class _MyAppState extends State<MyApp> {
  int currentIndex = 0;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Softcorp Core Demo',
      home: SplitScreen(
        footer: const SizedBox(height: 100, child: DefaultSoftcorpFooter()),
        logo: Image.asset(
          "assets/logos/softcorp_color_text.png",
        ),
        lightLogo: Image.asset(
          "assets/logos/softcorp_color_text.png",
        ),
        backgroundImage: Image.asset("assets/covers/cover1.jpg"),
        logoText: Text("Softcorp"),
        backgroundColor: Colors.red,
        leftChild: Container(
          margin: const EdgeInsets.all(defaultPadding * 2),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisAlignment: MainAxisAlignment.center,
            children: const [
              Text(
                "Softcorp Connect will securely authenticate your credentials",
                style: TextStyle(
                    color: Colors.white,
                    fontSize: 25,
                    fontWeight: FontWeight.w500),
              ),
              SizedBox(
                height: defaultPadding,
              ),
              Text(
                "You can view and manage who and what data you have given access to afterwards through our mobile application.",
                style: TextStyle(
                    color: Colors.white60,
                    fontSize: 18,
                    fontWeight: FontWeight.w500),
              ),
              DefaultSpinner(
                backgroundColor: Colors.transparent,
                size: 200,
              ),
            ],
          ),
        ),
        rightChild: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            DefaultFormField(
                textEditingController: TextEditingController(),
                textInputType: TextInputType.text,
                hint: "This is some hint",
                addDefaultBorder: true,
                prefixIcon: Icons.lock_rounded,
                label: "My Label"),
            DefaultMultiSelect(
                items: const {
                  "Item 1": "Item 1",
                  "Item 2": "Item 2",
                  "Item 3": "Item 3",
                },
                title: "Multi-select title",
                onConfirm: (values) {
                  // ignore: avoid_print
                  for (var element in values) {
                    print(element);
                  }
                }),
            DefaultListForm(
              textInputType: TextInputType.number,
              label: "Multi Form Field",
              hint: "Here is no hint",
              controller: DefaultListFormController(),
            ),
            DefaultDropdownFormField(
              prefixIcon: Icons.person,
              label: "Gender",
              items: const ["Male", "Female", "Other"],
              onChanged: (String? newValue) {
                print(newValue);
              },
              hint: "Choose a gender",
            ),
            DefaultLoadingButton(
              onPressed: () {
                print("hello");
              },
              buttonState: ButtonState.idle,
              icon: Icons.create_rounded,
              title: "Test button",
              backgroundColor: Colors.black,
            ),
            DefaultHeaderCard(
              backgroundColor: defaultCardColor,
              child: const Text("Test 1"),
              title: "Title for Default Header Card",
              subtitle: "Subtitle for Default Header Card",
              icon: const Icon(
                Icons.home_work_outlined,
                color: Colors.white,
                size: 50,
              ),
            ),
            DefaultHeaderCard(
              backgroundColor: defaultCardColor,
              child: const Text("Test 1"),
              title: "Title for Default Header Card",
              subtitle: "Subtitle for Default Header Card",
              icon: WebsafeSvg.asset(
                "assets/logos/softcorp-color.svg",
                height: 50,
              ),
              tabBarEnabled: true,
              currentIndex: currentIndex,
              onTabChange: (int? value) {
                setState(() {
                  currentIndex = value ?? 0;
                });
              },
              tabs: [
                ProfileDetailsTab(
                  icon: Icons.business,
                  name: "Tab 1",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 1");
                  },
                ),
                ProfileDetailsTab(
                  icon: Icons.money_rounded,
                  name: "Tab 2",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 2");
                  },
                ),
                ProfileDetailsTab(
                  icon: Icons.map_rounded,
                  name: "Tab 3",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 3");
                  },
                ),
              ],
            ),
            DefaultProfileCard(
              width: 800,
              height: 320,
              direction: Axis.horizontal,
              title: "This is not a title",
              subTitle: "This is not a subtitle",
              tabBarEnabled: true,
              currentIndex: currentIndex,
              onTabChange: (int? value) {
                setState(() {
                  currentIndex = value ?? 0;
                });
              },
              tabs: [
                ProfileDetailsTab(
                  icon: Icons.business,
                  name: "Tab 1",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 1");
                  },
                ),
                ProfileDetailsTab(
                  icon: Icons.money_rounded,
                  name: "Tab 2",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 2");
                  },
                ),
                ProfileDetailsTab(
                  icon: Icons.map_rounded,
                  name: "Tab 3",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 3");
                  },
                ),
              ],
              actionsEnabled: true,
              actionItemsLabelValueMap: const {
                "Key 1": "Value 1",
                "Key 2": "Value 2",
                "Key 3": "Value 3",
              },
              onSelectActionItem: (val) {
                // ignore: avoid_print
                print(val);
              },
              iconSize: 80,
              icon: const Icon(
                Icons.business_rounded,
                color: defaultBackgroundColor,
                size: 50,
              ),
            ),
            DefaultProfileCard(
              width: 800,
              height: 500,
              direction: Axis.vertical,
              title: "This is not a title",
              subTitle: "This is not a subtitle",
              tabBarEnabled: true,
              currentIndex: currentIndex,
              onTabChange: (int? value) {
                setState(() {
                  currentIndex = value ?? 0;
                });
              },
              tabs: [
                ProfileDetailsTab(
                  icon: Icons.business,
                  name: "Tab 1",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 1");
                  },
                ),
                ProfileDetailsTab(
                  icon: Icons.money_rounded,
                  name: "Tab 2",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 2");
                  },
                ),
                ProfileDetailsTab(
                  icon: Icons.map_rounded,
                  name: "Tab 3",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 3");
                  },
                ),
              ],
              actionsEnabled: true,
              actionItemsLabelValueMap: const {
                "Key 1": "Value 1",
                "Key 2": "Value 2",
                "Key 3": "Value 3",
              },
              onSelectActionItem: (val) {
                // ignore: avoid_print
                print(val);
              },
              iconSize: 80,
              icon: const Icon(
                Icons.business_rounded,
                color: defaultBackgroundColor,
                size: 50,
              ),
            ),
          ],
        ),
      ),
    );
  }
}
