import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/responsive/responsive.dart';

class SplitScreen extends StatelessWidget {
  final Widget leftChild;
  final Widget rightChild;
  final Image? logo;
  final Text? logoText;
  final Image? backgroundImage;
  final Widget? footer;
  final Color? backgroundColor;
  final Image? lightLogo;
  final double? footerHeight;
  final double? logoSize;
  const SplitScreen({
    Key? key,
    required this.leftChild,
    required this.rightChild,
    this.backgroundImage,
    this.footer,
    this.backgroundColor,
    this.logo,
    this.logoText,
    this.lightLogo,
    this.logoSize,
    this.footerHeight,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: backgroundColor ?? defaultBackgroundColor,
      body: SafeArea(
        child: SingleChildScrollView(
          child: Container(
            constraints:
                BoxConstraints(minHeight: MediaQuery.of(context).size.height),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                if (logo != null && !Responsive.isDesktop(context))
                  Padding(
                    padding: const EdgeInsets.all(defaultPadding),
                    child: Align(
                      child: Column(
                        children: [
                          Image(
                            image: logo!.image,
                            height: logoSize ?? 55,
                          ),
                          const SizedBox(height: 5),
                          logoText ?? const Text(""),
                        ],
                      ),
                      alignment: Alignment.topLeft,
                    ),
                  ),
                IntrinsicHeight(
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      if (Responsive.isDesktop(context))
                        Expanded(
                          flex: 1,
                          child: Container(
                            constraints: BoxConstraints(
                                minHeight: MediaQuery.of(context).size.height -
                                    (footerHeight ?? 0)),
                            decoration: backgroundImage != null
                                ? BoxDecoration(
                                    image: DecorationImage(
                                      image: backgroundImage!.image,
                                      fit: BoxFit.cover,
                                    ),
                                  )
                                : const BoxDecoration(
                                    gradient:
                                        LinearGradient(colors: darkGradient),
                                  ),
                            child: Column(
                              children: [
                                if (lightLogo != null &&
                                    Responsive.isDesktop(context))
                                  Padding(
                                    padding:
                                        const EdgeInsets.all(defaultPadding),
                                    child: Align(
                                      child: Column(
                                        children: [
                                          Image(
                                            image: lightLogo!.image,
                                            height: logoSize ?? 55,
                                          ),
                                          const SizedBox(height: 5),
                                          logoText ?? const Text(""),
                                        ],
                                      ),
                                      alignment: Alignment.topLeft,
                                    ),
                                  ),
                                if (lightLogo == null &&
                                    logo != null &&
                                    Responsive.isDesktop(context))
                                  Padding(
                                    padding:
                                        const EdgeInsets.all(defaultPadding),
                                    child: Align(
                                      child: Column(
                                        children: [
                                          Image(
                                            image: logo!.image,
                                            height: 55,
                                            color: Colors.white,
                                          ),
                                          const SizedBox(height: 5),
                                          logoText ?? const Text(""),
                                        ],
                                      ),
                                      alignment: Alignment.topLeft,
                                    ),
                                  ),
                                leftChild,
                              ],
                            ),
                          ),
                        ),
                      Expanded(
                        flex: 1,
                        child: rightChild,
                      ),
                    ],
                  ),
                ),
                Column(
                  children: [
                    if (!Responsive.isDesktop(context))
                      Container(
                        decoration: backgroundImage != null
                            ? BoxDecoration(
                                image: DecorationImage(
                                  image: backgroundImage!.image,
                                  fit: BoxFit.cover,
                                ),
                              )
                            : const BoxDecoration(
                                gradient: LinearGradient(colors: darkGradient),
                              ),
                        child: leftChild,
                      ),
                    footer ?? const SizedBox(),
                  ],
                )
              ],
            ),
          ),
        ),
      ),
    );
  }
}
